@@ -1,6 +1,6 @@
 /*
  * The Python Imaging Library.
- * $Id: Pack.c 2134 2004-10-06 08:55:20Z fredrik $
+ * $Id$
  *
  * code to pack raw data
  *
@@ -17,8 +17,9 @@
  * 1998-07-12 fl   Added I 16 packer
  * 1999-02-03 fl   Added BGR packers
  * 2003-09-26 fl   Added LA/PA packers
+ * 2006-06-22 fl   Added CMYK;I packer
  *
- * Copyright (c) 1997-2003 by Secret Labs AB.
+ * Copyright (c) 1997-2006 by Secret Labs AB.
  * Copyright (c) 1996-1997 by Fredrik Lundh.
  *
  * See the README file for information on usage and redistribution.
@@ -27,14 +28,17 @@
 
 #include "Imaging.h"
 
-
 #define	R 0
 #define	G 1
 #define	B 2
 #define	X 3
-
 #define	A 3
 
+#define	C 0
+#define	M 1
+#define	Y 2
+#define	K 3
+
 /* byte swapping macros */
 
 #define C16N\
@@ -283,6 +287,34 @@ ImagingPackXBGR(UINT8* out, const UINT8* in, int pixels)
     }
 }
 
+void
+ImagingPackBGRA(UINT8* out, const UINT8* in, int pixels)
+{
+    int i;
+    /* BGRX, reversed bytes with right padding */
+    for (i = 0; i < pixels; i++) {
+	out[0] = in[B];
+	out[1] = in[G];
+	out[2] = in[R];
+	out[3] = in[A];
+	out += 4; in += 4;
+    }
+}
+
+void
+ImagingPackABGR(UINT8* out, const UINT8* in, int pixels)
+{
+    int i;
+    /* XBGR, reversed bytes with left padding */
+    for (i = 0; i < pixels; i++) {
+	out[0] = in[A];
+	out[1] = in[B];
+	out[2] = in[G];
+	out[3] = in[R];
+	out += 4; in += 4;
+    }
+}
+
 static void
 packRGBL(UINT8* out, const UINT8* in, int pixels)
 {
@@ -368,6 +400,15 @@ copy4(UINT8* out, const UINT8* in, int pixels)
     memcpy(out, in, 4*pixels);
 }
 
+static void
+copy4I(UINT8* out, const UINT8* in, int pixels)
+{
+    /* RGBA, CMYK quadruples, inverted */
+    int i;
+    for (i = 0; i < pixels*4; i++)
+	out[i] = ~in[i];
+}
+
 static void
 band0(UINT8* out, const UINT8* in, int pixels)
 {
@@ -447,6 +488,9 @@ static struct {
     {"RGBA",	"RGBA",		32,	copy4},
     {"RGBA",	"RGBA;L",	32,	packRGBXL},
     {"RGBA",	"RGB",		24,	ImagingPackRGB},
+    {"RGBA",	"BGR",		24,	ImagingPackBGR},
+    {"RGBA",	"BGRA",		32,	ImagingPackBGRA},
+    {"RGBA",	"ABGR",		32,	ImagingPackABGR},
     {"RGBA",   	"R",            8,      band0},
     {"RGBA",   	"G",            8,      band1},
     {"RGBA",   	"B",            8,      band2},
@@ -456,6 +500,9 @@ static struct {
     {"RGBX",	"RGBX",		32,	copy4},
     {"RGBX",	"RGBX;L",	32,	packRGBXL},
     {"RGBX",	"RGB",		32,	ImagingPackRGB},
+    {"RGBX",	"BGR",		32,	ImagingPackBGR},
+    {"RGBX",	"BGRX",		32,	ImagingPackBGRX},
+    {"RGBX",	"XBGR",		32,	ImagingPackXBGR},
     {"RGBX",   	"R",            8,      band0},
     {"RGBX",   	"G",            8,      band1},
     {"RGBX",   	"B",            8,      band2},
@@ -463,6 +510,7 @@ static struct {
 
     /* colour separation */
     {"CMYK",	"CMYK",		32,	copy4},
+    {"CMYK",	"CMYK;I",	32,	copy4I},
     {"CMYK",	"CMYK;L",	32,	packRGBXL},
     {"CMYK",   	"C",            8,      band0},
     {"CMYK",   	"M",            8,      band1},
@@ -492,6 +540,7 @@ static struct {
     /* storage modes */
     {"I;16", 	"I;16",		16,	copy2},
     {"I;16B", 	"I;16B",	16,	copy2},
+    {"I;16L", 	"I;16L",	16,	copy2},
     {"BGR;15", 	"BGR;15",	16,	copy2},
     {"BGR;16", 	"BGR;16",	16,	copy2},
     {"BGR;24", 	"BGR;24",	24,	copy3},
