@@ -1,6 +1,6 @@
 /*
  * The Python Imaging Library
- * $Id: Palette.c 2289 2005-02-09 21:29:01Z fredrik $
+ * $Id$
  *
  * imaging palette object
  *
@@ -30,13 +30,13 @@ ImagingPaletteNew(const char* mode)
     int i;
     ImagingPalette palette;
 
+    if (strcmp(mode, "RGB") && strcmp(mode, "RGBA"))
+	return (ImagingPalette) ImagingError_ModeError();
+
     palette = calloc(1, sizeof(struct ImagingPaletteInstance));
     if (!palette)
 	return (ImagingPalette) ImagingError_MemoryError();
 
-    if (strcmp(mode, "RGB") && strcmp(mode, "RGBA"))
-	return (ImagingPalette) ImagingError_ModeError();
-
     strcpy(palette->mode, mode);
 
     /* Initialize to ramp */
@@ -290,7 +290,7 @@ ImagingPaletteCachePrepare(ImagingPalette palette)
 
 	palette->cache = (INT16*) malloc(entries * sizeof(INT16));
 	if (!palette->cache) {
-	    ImagingError_MemoryError();
+	    (void) ImagingError_MemoryError();
 	    return -1;
 	}
 
