@@ -1,6 +1,6 @@
 /*
  * The Python Imaging Library.
- * $Id: //modules/pil/libImaging/Zip.h#3 $
+ * $Id$
  *
  * declarations for the ZIP codecs
  *
@@ -49,5 +49,9 @@ typedef struct {
     UINT8* output;		/* output data */
 
     int prefix;			/* size of filter prefix (0 for TIFF data) */
+    
+    int interlaced;		/* is the image interlaced? (PNG) */
+    
+    int pass;			/* current pass of the interlaced image (PNG) */
 
 } ZIPSTATE;
